import sys
from optparse import OptionParser
from youtube2mp3 import __version__

def show_version(option, opt, value, parser):
    print("Version: %s" %  __version__)
    sys.exit(0)

usage = "usage: %prog [options] arg1 arg2"
parser = OptionParser(usage=usage)
parser.add_option("-d", "--directory", dest="directory", help="directory to store the files")
parser.add_option("-y", "--youtube-url", dest="youtube_url", help="link to a youtube video or playlist")
parser.add_option("-V", "--version", dest="version", help="show version and exit", action="callback", callback=show_version)
(options, args) = parser.parse_args()



from __future__ import unicode_literals
import youtube_dl
import os, sys
from options import options
from mutagen.easyid3 import EasyID3


class Youtube2mp3(object):
    FILES = []

    def __init(self):
        os.chdir(options.directory)

    def run(self):
        if not options.directory:
            print("a directory \"-d\" where to save the files must be set!")
            sys.exit(1)
        if not options.youtube_url:
            print("the youtube url \"-y\" is missing!")
            sys.exit(1)

        ydl_opts = {'format': 'bestaudio/best',
                    'postprocessors': [{
                        'key': 'FFmpegExtractAudio',
                        'preferredcodec': 'mp3',
                        'preferredquality': '192',
                    }],
                    'progress_hooks': [self._download_hook],}
        with youtube_dl.YoutubeDL(ydl_opts) as ydl:
            try:
                ydl.download([options.youtube_url])
            except (youtube_dl.utils.DownloadError, youtube_dl.utils.ContentTooShortError,
                youtube_dl.utils.ExtractorError) as e:
                print(e.message)
                sys.exit(1)

        self._set_id3()

    def _download_hook(self, d):
        if d['status'] == 'finished':
            self.FILES.append(d['filename'])
            print('Done downloading, now converting ...')
            print(d['filename'])


    def _set_id3(self):
        if self.FILES:
            for file in self.FILES:
                try:
                    base = os.path.basename(str(file))
                    name = os.path.splitext(base)[0]
                except Exception:
                    continue
                (artist, title, code) = name.split('-')
                print("[tagging]: %s" % name + '.mp3')
                file = EasyID3(name + '.mp3')
                file['title'] = title
                file['artist'] = artist
                file.save()


def main():
    y2mp3 = Youtube2mp3()
    y2mp3.run()



from codecs import open
from os.path import abspath, dirname, join
from setuptools import setup, find_packages
from youtube2mp3 import __version__, __author__


this_dir = abspath(dirname(__file__))
with open(join(this_dir, 'README.rst'), encoding='utf-8') as file:
    long_description = file.read()

setup(
    name = 'youtube2mp3',
    version = __version__,
    description = 'Commandline tool to convert youtube videos to tagged mp3 files',
    long_description = long_description,
    url = 'https://github.com/pfitzer/youtube2mp3.git',
    author = __author__,
    author_email = 'michael@mp-development.de',
    license = 'MIT',
    install_requires = ['youtube-dl', 'mutagen'],
    keywords = 'youtube mp3',
    packages = find_packages(),
    entry_points = {
        'console_scripts': [
            'youtube2mp3=youtube2mp3.cli:main',
        ],
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: MIT License',
        'Environment :: Console',
        'Intended Audience :: End Users/Desktop',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Topic :: Multimedia :: Video :: Conversion'
    ]
)